@@ -1,5 +1,5 @@
 ################################################################################
-# Author: Ben Baldwin, Sebastian Carl
+# Author: Ben Baldwin, Sebastian Carl, Tan Ho
 # Stlyeguide: styler::tidyverse_style()
 ################################################################################
 
@@ -14,6 +14,8 @@
 #' the play description; e.g. 24-M.Lynch instead of M.Lynch.
 #' The function also standardizes team abbreviations so that, for example,
 #' the Chargers are always represented by 'LAC' regardless of which year it was.
+#' Starting in 2022, play-by-play data was missing gsis player IDs of rookies.
+#' This functions tries to fix as many as possible.
 #' @seealso For information on parallel processing and progress updates please
 #' see [nflfastR].
 #' @return The input Data Frame of the parameter 'pbp' with the following columns
@@ -50,9 +52,60 @@ clean_pbp <- function(pbp, ...) {
   if (nrow(pbp) == 0) {
     user_message("Nothing to clean. Return passed data frame.", "info")
     r <- pbp
-  } else{
+  } else {
     user_message("Cleaning up play-by-play...", "todo")
 
+    if(any(pbp$season >= 2022)){
+
+      # user_message("Loading pbp player ID patch files", "info")
+
+      patch_seasons <- unique(pbp$season[pbp$season >= 2022])
+
+      patch_ids <- nflreadr::load_from_url(
+        glue::glue("https://github.com/nflverse/nflverse-data/releases/download/misc/pbp_patch_ids_{patch_seasons}.rds")
+      ) %>% suppressMessages()
+
+      patchable_ids <- pbp  %>%
+        dplyr::select(
+          dplyr::any_of(c(
+            "game_id", "play_id",
+            "passer_id", "passer_name" = "passer",
+            "receiver_id", "receiver_name" = "receiver",
+            "rusher_id", "rusher_name" = "rusher",
+            "fantasy_id", "fantasy_name" = "fantasy",
+            "fantasy_player_name"
+          )),
+          dplyr::matches("player_id|player_name")
+        )  %>%
+        tidyr::pivot_longer(
+          cols = -c("game_id","play_id"),
+          names_to = c("stat",".value"),
+          names_pattern = c("(.+)_(id|name)"),
+          values_drop_na = TRUE
+        )  %>%
+        dplyr::filter(is.na(.data$id)) %>%
+        dplyr::left_join(patch_ids, by = c("game_id","play_id","name"))  %>%
+        dplyr::mutate(
+          id = dplyr::coalesce(.data$id,.data$gsis_id),
+          gsis_id = NULL,
+          club_code = NULL,
+          name = NULL
+        )  %>%
+        tidyr::pivot_wider(
+          names_from = "stat",
+          values_from = "id",
+          names_glue = "{stat}_id"
+        )
+
+      if(nrow(patchable_ids) > 0){
+        pbp <- tibble::tibble(pbp)  %>%
+          dplyr::rows_patch(patchable_ids, by = c("game_id","play_id"))
+      }
+
+      # cli::cli_alert_success("{my_time()} | Patched {nrow(patchable_ids)} missing gsis_id field{?s}")
+
+    }
+
     # drop existing values of clean_pbp
     pbp <- pbp %>% dplyr::select(-tidyselect::any_of(drop.cols))
 
@@ -106,7 +159,7 @@ clean_pbp <- function(pbp, ...) {
         pass = dplyr::if_else(
           stringr::str_detect(.data$desc, "(backward pass)|(Backward pass)") & !is.na(.data$rusher),
           0, .data$pass
-          ),
+        ),
         # and make sure there's no pass on a kickoff (sometimes there's forward pass on kickoff but that's not a pass play)
         pass = dplyr::case_when(
           .data$kickoff_attempt == 1 ~ 0,
@@ -159,6 +212,7 @@ clean_pbp <- function(pbp, ...) {
           receiver_player_name == "JulioJones" ~ "J.Jones",
           receiver_player_name == "Andre' Davis" ~ "A.Davis",
           receiver_player_name == "A.al-Jabbar" ~ "A.al-Jabbar",
+          receiver_player_name == "A.St. Brown" ~ "A.St. Brown",
           TRUE ~ receiver
         ),
         first_down = dplyr::if_else(.data$first_down_rush == 1 | .data$first_down_pass == 1 | .data$first_down_penalty == 1, 1, 0),
